@@ -1,6 +1,8 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
-from flexget.plugin import register_plugin, priority, get_plugin_by_name, PluginError
+
+from flexget import plugin
+from flexget.event import event
 
 log = logging.getLogger('imdb_required')
 
@@ -17,14 +19,18 @@ class FilterImdbRequired(object):
 
     schema = {'type': 'boolean'}
 
-    @priority(32)
-    def on_task_filter(self, task):
+    @plugin.priority(32)
+    def on_task_filter(self, task, config):
+        if not config:
+            return
         for entry in task.entries:
             try:
-                get_plugin_by_name('imdb_lookup').instance.lookup(entry)
-            except PluginError:
+                plugin.get_plugin_by_name('imdb_lookup').instance.lookup(entry)
+            except plugin.PluginError:
                 entry.reject('imdb required')
             if 'imdb_url' not in entry and 'imdb_id' not in entry:
                 entry.reject('imdb required')
 
-register_plugin(FilterImdbRequired, 'imdb_required')
+@event('plugin.register')
+def register_plugin():
+    plugin.register(FilterImdbRequired, 'imdb_required', api_ver=2)
