@@ -1,8 +1,9 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
 
+from flexget import plugin
 from flexget.config_schema import one_or_more
-from flexget.plugin import register_plugin, priority
+from flexget.event import event
 
 log = logging.getLogger('require_field')
 
@@ -18,7 +19,7 @@ class FilterRequireField(object):
 
     schema = one_or_more({"type": "string"})
 
-    @priority(32)
+    @plugin.priority(32)
     def on_task_filter(self, task, config):
         if isinstance(config, basestring):
             config = [config]
@@ -29,4 +30,6 @@ class FilterRequireField(object):
                     break
 
 
-register_plugin(FilterRequireField, 'require_field', api_ver=2)
+@event('plugin.register')
+def register_plugin():
+    plugin.register(FilterRequireField, 'require_field', api_ver=2)
