@@ -3,7 +3,9 @@ import subprocess
 import logging
 import sys
 from UserDict import UserDict
-from flexget.plugin import register_plugin, phase_methods
+
+from flexget import plugin
+from flexget.event import event
 from flexget.utils.template import render_from_entry, render_from_task, RenderError
 
 log = logging.getLogger('exec')
@@ -129,7 +131,7 @@ class PluginExec(object):
                     continue
 
                 log.debug('phase_name: %s operation: %s cmd: %s' % (phase_name, operation, cmd))
-                if task.manager.options.test:
+                if task.options.test:
                     log.info('Would execute: %s' % cmd)
                 else:
                     # Make sure the command can be encoded into appropriate encoding, don't actually encode yet,
@@ -154,7 +156,7 @@ class PluginExec(object):
                 log.error('Error rendering `%s`: %s' % (cmd, e))
             else:
                 log.debug('phase cmd: %s' % cmd)
-                if task.manager.options.test:
+                if task.options.test:
                     log.info('Would execute: %s' % cmd)
                 else:
                     self.execute_cmd(cmd, allow_background, config['encoding'])
@@ -162,7 +164,7 @@ class PluginExec(object):
     def __getattr__(self, item):
         """Creates methods to handle task phases."""
         for phase in self.HANDLED_PHASES:
-            if item == phase_methods[phase]:
+            if item == plugin.phase_methods[phase]:
                 # A phase method we handle has been requested
                 break
         else:
@@ -177,4 +179,6 @@ class PluginExec(object):
         return phase_handler
 
 
-register_plugin(PluginExec, 'exec', api_ver=2)
+@event('plugin.register')
+def register_plugin():
+    plugin.register(PluginExec, 'exec', api_ver=2)
